# Hybrid Groups

<p align="left">
    <a href="https://gradion-ai.github.io/hybrid-groups/"><img alt="Website" src="https://img.shields.io/website?url=https%3A%2F%2Fgradion-ai.github.io%2Fhybrid-groups%2F&up_message=online&down_message=offline&label=docs"></a>
    <a href="https://pypi.org/project/hybrid-groups/"><img alt="PyPI - Version" src="https://img.shields.io/pypi/v/hybrid-groups?color=blue"></a>
    <a href="https://github.com/gradion-ai/hybrid-groups/releases"><img alt="GitHub Release" src="https://img.shields.io/github/v/release/gradion-ai/hybrid-groups"></a>
    <a href="https://github.com/gradion-ai/hybrid-groups/actions"><img alt="GitHub Actions Workflow Status" src="https://img.shields.io/github/actions/workflow/status/gradion-ai/hybrid-groups/test.yml"></a>
    <a href="https://github.com/gradion-ai/hybrid-groups/blob/main/LICENSE"><img alt="GitHub License" src="https://img.shields.io/github/license/gradion-ai/hybrid-groups?color=blueviolet"></a>
</p>

[*Hybrid Groups*](https://gradion-ai.github.io/hybrid-groups/) integrates human team collaboration with AI agents. Unlike typical AI applications built for single-user interaction, *Hybrid Groups* enables AI agents to have conversations with multiple users simultaneously, recognizing each user’s identity and respecting their unique preferences and permissions.

<div align="left">
  <a href="https://www.youtube.com/watch?v=OxOmRsNin4o">
    <img src="https://raw.githubusercontent.com/gradion-ai/hybrid-groups/main/docs/images/overview/video.jpg" alt="Watch the video" style="width: 50%;">
  </a>
</div>

Agents can also proactively support team discussions by contributing relevant information or initiating helpful actions. *Hybrid Groups* currently supports Slack and GitHub as team collaboration platforms, and is extensible to other platforms.

> [!TIP]
> Check the [tutorial](https://gradion-ai.github.io/hybrid-groups/tutorial) for a feature overview with examples.

<table>
<tr>
<td><a href="https://gradion-ai.github.io/hybrid-groups/images/overview/overview-1.png" target="_blank"><img src="https://gradion-ai.github.io/hybrid-groups/images/overview/overview-1.png" alt="Hybrid Groups" /></a></td>
<td><a href="https://gradion-ai.github.io/hybrid-groups/images/overview/overview-3.png" target="_blank"><img src="https://gradion-ai.github.io/hybrid-groups/images/overview/overview-3-crop.png" alt="Hybrid Groups" /></a></td>
</tr>
</table>
